==> corekeyboard-2.7.0.tar.gz: corekeyboard-v2.7.0/settings/settings.cpp <==
/*
	*
	* This file is a part of CoreKeyboard.
	* An on-screenkeyboard for CuboCore Application Suite
	* Copyright 2019 Britanicus <marcusbritanicus@gmail.com>
	*

	*
	* This program is free software; you can redistribute it and/or modify
	* it under the terms of the GNU General Public License as published by
	* the Free Software Foundation; either version 3 of the License, or
	* (at your option) any later version.
	*

	*
	* This program is distributed in the hope that it will be useful,
	* but WITHOUT ANY WARRANTY; without even the implied warranty of
	* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	* GNU General Public License for more details.
	*

	*
	* You should have received a copy of the GNU General Public License
	* along with this program; if not, see {http://www.gnu.org/licenses/}.
	*
*/

#include "settings.h"


settingsManage *CKSettings::ckSett = settingsManage::initialize( true );

/* Get the key layout: moble or desktop */
int CKSettings::keyboardLayout() {

	return ( int )ckSett->value( "CoreKeyboard", "Layout" );
};

/* Get the keyboard mode: fixed or compact */
int CKSettings::keyboardMode() {

	return ( int )ckSett->value( "CoreKeyboard", "Mode" );
};

/* Show word suggestions */
bool CKSettings::showSuggestions() {

	return ( bool )ckSett->value( "CoreKeyboard", "AutoSuggest" );
};

/* Key borders */
bool CKSettings::showKeyBorders() {

	return ( bool )ckSett->value( "CoreKeyboard", "KeyBorders" );
};

/* Key Mapping */
QString CKSettings::keyMapping() {

	if ( keyboardLayout() == Layout::Mobile )
		return ":/resources/en_US_mobile.keymap";

	else
		return ":/resources/en_US.keymap";
};

/* Extra desktop keys */
bool CKSettings::showExtraDesktopKeys() {

	return ( bool )ckSett->value( "CoreKeyboard", "ExtraDessktopKeys" );
};

/* Keyboard Font */
QString CKSettings::buttonFontName() {

	return ( QString )ckSett->value( "CoreKeyboard", "Font" );
};

==> corekeyboard-2.8.0.tar.gz: corekeyboard-v2.8.0/settings/settings.cpp <==
/*
	*
	* This file is a part of CoreKeyboard.
	* An on-screenkeyboard for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
	*

	*
	* This program is free software; you can redistribute it and/or modify
	* it under the terms of the GNU General Public License as published by
	* the Free Software Foundation; either version 3 of the License, or
	* (at your option) any later version.
	*

	*
	* This program is distributed in the hope that it will be useful,
	* but WITHOUT ANY WARRANTY; without even the implied warranty of
	* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	* GNU General Public License for more details.
	*

	*
	* You should have received a copy of the GNU General Public License
	* along with this program; if not, see {http://www.gnu.org/licenses/}.
	*
*/

#include "settings.h"


settingsManage *CKSettings::ckSett = settingsManage::initialize( true );

/* Get the key layout: moble or desktop */
int CKSettings::keyboardLayout() {

    return static_cast<int>(ckSett->value("CoreKeyboard", "Layout" ));
};

/* Get the keyboard mode: fixed or compact */
int CKSettings::keyboardMode() {

    return static_cast<int>(ckSett->value( "CoreKeyboard", "Mode" ));
};

/* Show word suggestions */
bool CKSettings::showSuggestions() {

    return static_cast<bool>(ckSett->value( "CoreKeyboard", "AutoSuggest" ));
};

/* Key borders */
//bool CKSettings::showKeyBorders() {

//	return ( bool )ckSett->value( "CoreKeyboard", "KeyBorders" );
//};

/* Key Mapping */
QString CKSettings::keyMapping() {

	if ( keyboardLayout() == Layout::Mobile )
		return ":/resources/en_US_mobile.keymap";

	else
		return ":/resources/en_US.keymap";
};

/* Extra desktop keys */
bool CKSettings::showExtraDesktopKeys() {

    return static_cast<bool>(ckSett->value( "CoreKeyboard", "ExtraDessktopKeys" ));
};

/* Keyboard Font */
QString CKSettings::buttonFontName() {

    return static_cast<QString>(ckSett->value(  "CoreKeyboard", "Font" ));
};
